alphashape package
==================

Module contents
---------------

.. automodule:: alphashape.alphashape
    :members:
    :undoc-members:
    :show-inheritance:

.. include:: gen_modules/backreferences/alphashape.alphashape.examples

.. raw:: html

       <div style='clear:both'></div>

.. automodule:: alphashape.optimizealpha
    :members:
    :undoc-members:
    :show-inheritance:

.. include:: gen_modules/backreferences/alphashape.optimizealpha.examples

.. raw:: html

       <div style='clear:both'></div>
